@@ -37,6 +37,8 @@ function main() {
     prettyTimeTest();
     prettyDistanceTest();
     normalizeStringTest();
+    validWebsiteTest();
+    firstToLocaleUpperCaseTest();
 }
 
 function osmTypeToStringTest() {
@@ -101,3 +103,19 @@ function normalizeStringTest() {
     JsUnit.assertEquals('aao', Utils.normalizeString('åäö'));
     JsUnit.assertEquals('aao', Utils.normalizeString('a\u030aa\u0308o\u0308'));
 }
+
+function validWebsiteTest() {
+    JsUnit.assertEquals(true, Utils.isValidWebsite("https://gnome.org"));
+    JsUnit.assertEquals(true, Utils.isValidWebsite("http://gnome.org"));
+    JsUnit.assertEquals(false, Utils.isValidWebsite("ftp://gnome.org"));
+    JsUnit.assertEquals(false, Utils.isValidWebsite("www.gnome.org"));
+    JsUnit.assertEquals(false, Utils.isValidWebsite("https:gnome.org"));
+}
+
+function firstToLocaleUpperCaseTest() {
+    JsUnit.assertEquals('Xxx', Utils.firstToLocaleUpperCase('xxx'));
+    JsUnit.assertEquals('Xxx', Utils.firstToLocaleUpperCase('Xxx'));
+    JsUnit.assertEquals('XXX', Utils.firstToLocaleUpperCase('XXX'));
+    JsUnit.assertEquals('فارسی', Utils.firstToLocaleUpperCase('فارسی'));
+    JsUnit.assertEquals('日本語', Utils.firstToLocaleUpperCase('日本語'));
+}
